netapp_ontap.models.storage_switch_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_switch_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageSwitchPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageSwitchPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET POST PATCH`

    Indicates whether the storage switch port is enabled.

  `mode: str GET POST PATCH`

    Storage switch port mode

    Valid choices:

    - unknown
    - auto
    - f_port
    - fl_port
    - e_port
    - te_port
    - u_port
    - g_port
    - other
    - ex_port
    - d_port
    - sim_port
    - ve_port
    - ae_port
    - af_port
  `name: str GET POST PATCH`

    Storage switch port name

  `sfp: StorageSwitchPortsSfp GET POST PATCH`

    The sfp field of the storage_switch_ports.

  `speed: Size GET POST PATCH`

    Storage switch port speed, in Gbps

  `state: str GET POST PATCH`

    Storage switch port state

    Valid choices:

    - error
    - online
    - offline
  `wwn: str GET POST PATCH`

    Storage switch port world wide name